/*
 * Copyright 2018 The gRPC Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.grpc.alts;

import static com.google.common.truth.Truth.assertThat;

import io.grpc.netty.InternalProtocolNegotiator.ProtocolNegotiator;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.JUnit4;

@RunWith(JUnit4.class)
public final class AltsChannelBuilderTest {

  @Test
  public void buildsNettyChannel() {
    AltsChannelBuilder builder =
        AltsChannelBuilder.forTarget("localhost:8080").enableUntrustedAltsForTesting();

    ProtocolNegotiator protocolNegotiator = builder.getProtocolNegotiatorForTest();
    assertThat(protocolNegotiator).isNotNull();
    // Avoids exposing this class
    assertThat(protocolNegotiator.getClass().getSimpleName())
        .isEqualTo("ClientAltsProtocolNegotiator");
  }
}
